/* MaterialDesignIcons.com */
@font-face {
  font-family: "Material Design Icons";
  src: url("../fonts/materialdesignicons-webfont.eot?v=1.4.57");
  src: url("../fonts/materialdesignicons-webfont.eot?#iefix&v=1.4.57") format("embedded-opentype"), url("../fonts/materialdesignicons-webfont.woff2?v=1.4.57") format("woff2"), url("../fonts/materialdesignicons-webfont.woff?v=1.4.57") format("woff"), url("../fonts/materialdesignicons-webfont.ttf?v=1.4.57") format("truetype"), url("../fonts/materialdesignicons-webfont.svg?v=1.4.57#materialdesigniconsregular") format("svg");
  font-weight: normal;
  font-style: normal;
}
.mdi {
  display: inline-block;
  font: normal normal normal 24px/1 "Material Design Icons";
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
}

.mdi-access-point:before {
  content: "\f101";
}

.mdi-access-point-network:before {
  content: "\f102";
}

.mdi-account:before {
  content: "\f103";
}

.mdi-account-alert:before {
  content: "\f104";
}

.mdi-account-box:before {
  content: "\f105";
}

.mdi-account-box-outline:before {
  content: "\f106";
}

.mdi-account-check:before {
  content: "\f107";
}

.mdi-account-circle:before {
  content: "\f108";
}

.mdi-account-convert:before {
  content: "\f109";
}

.mdi-account-key:before {
  content: "\f10a";
}

.mdi-account-location:before {
  content: "\f10b";
}

.mdi-account-minus:before {
  content: "\f10c";
}

.mdi-account-multiple:before {
  content: "\f10d";
}

.mdi-account-multiple-outline:before {
  content: "\f10e";
}

.mdi-account-multiple-plus:before {
  content: "\f10f";
}

.mdi-account-network:before {
  content: "\f110";
}

.mdi-account-off:before {
  content: "\f111";
}

.mdi-account-outline:before {
  content: "\f112";
}

.mdi-account-plus:before {
  content: "\f113";
}

.mdi-account-remove:before {
  content: "\f114";
}

.mdi-account-search:before {
  content: "\f115";
}

.mdi-account-star:before {
  content: "\f116";
}

.mdi-account-star-variant:before {
  content: "\f117";
}

.mdi-account-switch:before {
  content: "\f118";
}

.mdi-adjust:before {
  content: "\f119";
}

.mdi-air-conditioner:before {
  content: "\f11a";
}

.mdi-airballoon:before {
  content: "\f11b";
}

.mdi-airplane:before {
  content: "\f11c";
}

.mdi-airplane-off:before {
  content: "\f11d";
}

.mdi-airplay:before {
  content: "\f11e";
}

.mdi-alarm:before {
  content: "\f11f";
}

.mdi-alarm-check:before {
  content: "\f120";
}

.mdi-alarm-multiple:before {
  content: "\f121";
}

.mdi-alarm-off:before {
  content: "\f122";
}

.mdi-alarm-plus:before {
  content: "\f123";
}

.mdi-album:before {
  content: "\f124";
}

.mdi-alert:before {
  content: "\f125";
}

.mdi-alert-box:before {
  content: "\f126";
}

.mdi-alert-circle:before {
  content: "\f127";
}

.mdi-alert-octagon:before {
  content: "\f128";
}

.mdi-alert-outline:before {
  content: "\f129";
}

.mdi-alpha:before {
  content: "\f12a";
}

.mdi-alphabetical:before {
  content: "\f12b";
}

.mdi-amazon:before {
  content: "\f12c";
}

.mdi-amazon-clouddrive:before {
  content: "\f12d";
}

.mdi-ambulance:before {
  content: "\f12e";
}

.mdi-anchor:before {
  content: "\f12f";
}

.mdi-android:before {
  content: "\f130";
}

.mdi-android-debug-bridge:before {
  content: "\f131";
}

.mdi-android-studio:before {
  content: "\f132";
}

.mdi-apple:before {
  content: "\f133";
}

.mdi-apple-finder:before {
  content: "\f134";
}

.mdi-apple-ios:before {
  content: "\f135";
}

.mdi-apple-mobileme:before {
  content: "\f136";
}

.mdi-apple-safari:before {
  content: "\f137";
}

.mdi-appnet:before {
  content: "\f138";
}

.mdi-apps:before {
  content: "\f139";
}

.mdi-archive:before {
  content: "\f13a";
}

.mdi-arrange-bring-forward:before {
  content: "\f13b";
}

.mdi-arrange-bring-to-front:before {
  content: "\f13c";
}

.mdi-arrange-send-backward:before {
  content: "\f13d";
}

.mdi-arrange-send-to-back:before {
  content: "\f13e";
}

.mdi-arrow-all:before {
  content: "\f13f";
}

.mdi-arrow-bottom-drop-circle:before {
  content: "\f140";
}

.mdi-arrow-bottom-left:before {
  content: "\f141";
}

.mdi-arrow-bottom-right:before {
  content: "\f142";
}

.mdi-arrow-collapse:before {
  content: "\f143";
}

.mdi-arrow-down:before {
  content: "\f144";
}

.mdi-arrow-down-bold:before {
  content: "\f145";
}

.mdi-arrow-down-bold-circle:before {
  content: "\f146";
}

.mdi-arrow-down-bold-circle-outline:before {
  content: "\f147";
}

.mdi-arrow-down-bold-hexagon-outline:before {
  content: "\f148";
}

.mdi-arrow-expand:before {
  content: "\f149";
}

.mdi-arrow-left:before {
  content: "\f14a";
}

.mdi-arrow-left-bold:before {
  content: "\f14b";
}

.mdi-arrow-left-bold-circle:before {
  content: "\f14c";
}

.mdi-arrow-left-bold-circle-outline:before {
  content: "\f14d";
}

.mdi-arrow-left-bold-hexagon-outline:before {
  content: "\f14e";
}

.mdi-arrow-right:before {
  content: "\f14f";
}

.mdi-arrow-right-bold:before {
  content: "\f150";
}

.mdi-arrow-right-bold-circle:before {
  content: "\f151";
}

.mdi-arrow-right-bold-circle-outline:before {
  content: "\f152";
}

.mdi-arrow-right-bold-hexagon-outline:before {
  content: "\f153";
}

.mdi-arrow-top-left:before {
  content: "\f154";
}

.mdi-arrow-top-right:before {
  content: "\f155";
}

.mdi-arrow-up:before {
  content: "\f156";
}

.mdi-arrow-up-bold:before {
  content: "\f157";
}

.mdi-arrow-up-bold-circle:before {
  content: "\f158";
}

.mdi-arrow-up-bold-circle-outline:before {
  content: "\f159";
}

.mdi-arrow-up-bold-hexagon-outline:before {
  content: "\f15a";
}

.mdi-assistant:before {
  content: "\f15b";
}

.mdi-at:before {
  content: "\f15c";
}

.mdi-attachment:before {
  content: "\f15d";
}

.mdi-audiobook:before {
  content: "\f15e";
}

.mdi-auto-fix:before {
  content: "\f15f";
}

.mdi-auto-upload:before {
  content: "\f160";
}

.mdi-autorenew:before {
  content: "\f161";
}

.mdi-av-timer:before {
  content: "\f162";
}

.mdi-baby:before {
  content: "\f163";
}

.mdi-backburger:before {
  content: "\f164";
}

.mdi-backspace:before {
  content: "\f165";
}

.mdi-backup-restore:before {
  content: "\f166";
}

.mdi-bank:before {
  content: "\f167";
}

.mdi-barcode:before {
  content: "\f168";
}

.mdi-barcode-scan:before {
  content: "\f169";
}

.mdi-barley:before {
  content: "\f16a";
}

.mdi-barrel:before {
  content: "\f16b";
}

.mdi-basecamp:before {
  content: "\f16c";
}

.mdi-basket:before {
  content: "\f16d";
}

.mdi-basket-fill:before {
  content: "\f16e";
}

.mdi-basket-unfill:before {
  content: "\f16f";
}

.mdi-battery:before {
  content: "\f170";
}

.mdi-battery-10:before {
  content: "\f171";
}

.mdi-battery-20:before {
  content: "\f172";
}

.mdi-battery-30:before {
  content: "\f173";
}

.mdi-battery-40:before {
  content: "\f174";
}

.mdi-battery-50:before {
  content: "\f175";
}

.mdi-battery-60:before {
  content: "\f176";
}

.mdi-battery-70:before {
  content: "\f177";
}

.mdi-battery-80:before {
  content: "\f178";
}

.mdi-battery-90:before {
  content: "\f179";
}

.mdi-battery-alert:before {
  content: "\f17a";
}

.mdi-battery-charging:before {
  content: "\f17b";
}

.mdi-battery-charging-100:before {
  content: "\f17c";
}

.mdi-battery-charging-20:before {
  content: "\f17d";
}

.mdi-battery-charging-30:before {
  content: "\f17e";
}

.mdi-battery-charging-40:before {
  content: "\f17f";
}

.mdi-battery-charging-60:before {
  content: "\f180";
}

.mdi-battery-charging-80:before {
  content: "\f181";
}

.mdi-battery-charging-90:before {
  content: "\f182";
}

.mdi-battery-minus:before {
  content: "\f183";
}

.mdi-battery-negative:before {
  content: "\f184";
}

.mdi-battery-outline:before {
  content: "\f185";
}

.mdi-battery-plus:before {
  content: "\f186";
}

.mdi-battery-positive:before {
  content: "\f187";
}

.mdi-battery-unknown:before {
  content: "\f188";
}

.mdi-beach:before {
  content: "\f189";
}

.mdi-beaker:before {
  content: "\f18a";
}

.mdi-beaker-empty:before {
  content: "\f18b";
}

.mdi-beaker-empty-outline:before {
  content: "\f18c";
}

.mdi-beaker-outline:before {
  content: "\f18d";
}

.mdi-beats:before {
  content: "\f18e";
}

.mdi-beer:before {
  content: "\f18f";
}

.mdi-behance:before {
  content: "\f190";
}

.mdi-bell:before {
  content: "\f191";
}

.mdi-bell-off:before {
  content: "\f192";
}

.mdi-bell-outline:before {
  content: "\f193";
}

.mdi-bell-plus:before {
  content: "\f194";
}

.mdi-bell-ring:before {
  content: "\f195";
}

.mdi-bell-ring-outline:before {
  content: "\f196";
}

.mdi-bell-sleep:before {
  content: "\f197";
}

.mdi-beta:before {
  content: "\f198";
}

.mdi-bike:before {
  content: "\f199";
}

.mdi-bing:before {
  content: "\f19a";
}

.mdi-binoculars:before {
  content: "\f19b";
}

.mdi-bio:before {
  content: "\f19c";
}

.mdi-biohazard:before {
  content: "\f19d";
}

.mdi-bitbucket:before {
  content: "\f19e";
}

.mdi-black-mesa:before {
  content: "\f19f";
}

.mdi-blackberry:before {
  content: "\f1a0";
}

.mdi-blender:before {
  content: "\f1a1";
}

.mdi-blinds:before {
  content: "\f1a2";
}

.mdi-block-helper:before {
  content: "\f1a3";
}

.mdi-blogger:before {
  content: "\f1a4";
}

.mdi-bluetooth:before {
  content: "\f1a5";
}

.mdi-bluetooth-audio:before {
  content: "\f1a6";
}

.mdi-bluetooth-connect:before {
  content: "\f1a7";
}

.mdi-bluetooth-off:before {
  content: "\f1a8";
}

.mdi-bluetooth-settings:before {
  content: "\f1a9";
}

.mdi-bluetooth-transfer:before {
  content: "\f1aa";
}

.mdi-blur:before {
  content: "\f1ab";
}

.mdi-blur-linear:before {
  content: "\f1ac";
}

.mdi-blur-off:before {
  content: "\f1ad";
}

.mdi-blur-radial:before {
  content: "\f1ae";
}

.mdi-bone:before {
  content: "\f1af";
}

.mdi-book:before {
  content: "\f1b0";
}

.mdi-book-multiple:before {
  content: "\f1b1";
}

.mdi-book-multiple-variant:before {
  content: "\f1b2";
}

.mdi-book-open:before {
  content: "\f1b3";
}

.mdi-book-open-variant:before {
  content: "\f1b4";
}

.mdi-book-variant:before {
  content: "\f1b5";
}

.mdi-bookmark:before {
  content: "\f1b6";
}

.mdi-bookmark-check:before {
  content: "\f1b7";
}

.mdi-bookmark-music:before {
  content: "\f1b8";
}

.mdi-bookmark-outline:before {
  content: "\f1b9";
}

.mdi-bookmark-outline-plus:before {
  content: "\f1ba";
}

.mdi-bookmark-plus:before {
  content: "\f1bb";
}

.mdi-bookmark-remove:before {
  content: "\f1bc";
}

.mdi-border-all:before {
  content: "\f1bd";
}

.mdi-border-bottom:before {
  content: "\f1be";
}

.mdi-border-color:before {
  content: "\f1bf";
}

.mdi-border-horizontal:before {
  content: "\f1c0";
}

.mdi-border-inside:before {
  content: "\f1c1";
}

.mdi-border-left:before {
  content: "\f1c2";
}

.mdi-border-none:before {
  content: "\f1c3";
}

.mdi-border-outside:before {
  content: "\f1c4";
}

.mdi-border-right:before {
  content: "\f1c5";
}

.mdi-border-style:before {
  content: "\f1c6";
}

.mdi-border-top:before {
  content: "\f1c7";
}

.mdi-border-vertical:before {
  content: "\f1c8";
}

.mdi-bowling:before {
  content: "\f1c9";
}

.mdi-box:before {
  content: "\f1ca";
}

.mdi-box-cutter:before {
  content: "\f1cb";
}

.mdi-briefcase:before {
  content: "\f1cc";
}

.mdi-briefcase-check:before {
  content: "\f1cd";
}

.mdi-briefcase-download:before {
  content: "\f1ce";
}

.mdi-briefcase-upload:before {
  content: "\f1cf";
}

.mdi-brightness-1:before {
  content: "\f1d0";
}

.mdi-brightness-2:before {
  content: "\f1d1";
}

.mdi-brightness-3:before {
  content: "\f1d2";
}

.mdi-brightness-4:before {
  content: "\f1d3";
}

.mdi-brightness-5:before {
  content: "\f1d4";
}

.mdi-brightness-6:before {
  content: "\f1d5";
}

.mdi-brightness-7:before {
  content: "\f1d6";
}

.mdi-brightness-auto:before {
  content: "\f1d7";
}

.mdi-broom:before {
  content: "\f1d8";
}

.mdi-brush:before {
  content: "\f1d9";
}

.mdi-bug:before {
  content: "\f1da";
}

.mdi-bulletin-board:before {
  content: "\f1db";
}

.mdi-bullhorn:before {
  content: "\f1dc";
}

.mdi-bus:before {
  content: "\f1dd";
}

.mdi-cached:before {
  content: "\f1de";
}

.mdi-cake:before {
  content: "\f1df";
}

.mdi-cake-layered:before {
  content: "\f1e0";
}

.mdi-cake-variant:before {
  content: "\f1e1";
}

.mdi-calculator:before {
  content: "\f1e2";
}

.mdi-calendar:before {
  content: "\f1e3";
}

.mdi-calendar-blank:before {
  content: "\f1e4";
}

.mdi-calendar-check:before {
  content: "\f1e5";
}

.mdi-calendar-clock:before {
  content: "\f1e6";
}

.mdi-calendar-multiple:before {
  content: "\f1e7";
}

.mdi-calendar-multiple-check:before {
  content: "\f1e8";
}

.mdi-calendar-plus:before {
  content: "\f1e9";
}

.mdi-calendar-remove:before {
  content: "\f1ea";
}

.mdi-calendar-text:before {
  content: "\f1eb";
}

.mdi-calendar-today:before {
  content: "\f1ec";
}

.mdi-call-made:before {
  content: "\f1ed";
}

.mdi-call-merge:before {
  content: "\f1ee";
}

.mdi-call-missed:before {
  content: "\f1ef";
}

.mdi-call-received:before {
  content: "\f1f0";
}

.mdi-call-split:before {
  content: "\f1f1";
}

.mdi-camcorder:before {
  content: "\f1f2";
}

.mdi-camcorder-box:before {
  content: "\f1f3";
}

.mdi-camcorder-box-off:before {
  content: "\f1f4";
}

.mdi-camcorder-off:before {
  content: "\f1f5";
}

.mdi-camera:before {
  content: "\f1f6";
}

.mdi-camera-enhance:before {
  content: "\f1f7";
}

.mdi-camera-front:before {
  content: "\f1f8";
}

.mdi-camera-front-variant:before {
  content: "\f1f9";
}

.mdi-camera-iris:before {
  content: "\f1fa";
}

.mdi-camera-party-mode:before {
  content: "\f1fb";
}

.mdi-camera-rear:before {
  content: "\f1fc";
}

.mdi-camera-rear-variant:before {
  content: "\f1fd";
}

.mdi-camera-switch:before {
  content: "\f1fe";
}

.mdi-camera-timer:before {
  content: "\f1ff";
}

.mdi-candycane:before {
  content: "\f200";
}

.mdi-car:before {
  content: "\f201";
}

.mdi-car-battery:before {
  content: "\f202";
}

.mdi-car-connected:before {
  content: "\f203";
}

.mdi-car-wash:before {
  content: "\f204";
}

.mdi-carrot:before {
  content: "\f205";
}

.mdi-cart:before {
  content: "\f206";
}

.mdi-cart-outline:before {
  content: "\f207";
}

.mdi-cart-plus:before {
  content: "\f208";
}

.mdi-case-sensitive-alt:before {
  content: "\f209";
}

.mdi-cash:before {
  content: "\f20a";
}

.mdi-cash-100:before {
  content: "\f20b";
}

.mdi-cash-multiple:before {
  content: "\f20c";
}

.mdi-cash-usd:before {
  content: "\f20d";
}

.mdi-cast:before {
  content: "\f20e";
}

.mdi-cast-connected:before {
  content: "\f20f";
}

.mdi-castle:before {
  content: "\f210";
}

.mdi-cat:before {
  content: "\f211";
}

.mdi-cellphone:before {
  content: "\f212";
}

.mdi-cellphone-android:before {
  content: "\f213";
}

.mdi-cellphone-basic:before {
  content: "\f214";
}

.mdi-cellphone-dock:before {
  content: "\f215";
}

.mdi-cellphone-iphone:before {
  content: "\f216";
}

.mdi-cellphone-link:before {
  content: "\f217";
}

.mdi-cellphone-link-off:before {
  content: "\f218";
}

.mdi-cellphone-settings:before {
  content: "\f219";
}

.mdi-certificate:before {
  content: "\f21a";
}

.mdi-chair-school:before {
  content: "\f21b";
}

.mdi-chart-arc:before {
  content: "\f21c";
}

.mdi-chart-areaspline:before {
  content: "\f21d";
}

.mdi-chart-bar:before {
  content: "\f21e";
}

.mdi-chart-histogram:before {
  content: "\f21f";
}

.mdi-chart-line:before {
  content: "\f220";
}

.mdi-chart-pie:before {
  content: "\f221";
}

.mdi-check:before {
  content: "\f222";
}

.mdi-check-all:before {
  content: "\f223";
}

.mdi-checkbox-blank:before {
  content: "\f224";
}

.mdi-checkbox-blank-circle:before {
  content: "\f225";
}

.mdi-checkbox-blank-circle-outline:before {
  content: "\f226";
}

.mdi-checkbox-blank-outline:before {
  content: "\f227";
}

.mdi-checkbox-marked:before {
  content: "\f228";
}

.mdi-checkbox-marked-circle:before {
  content: "\f229";
}

.mdi-checkbox-marked-circle-outline:before {
  content: "\f22a";
}

.mdi-checkbox-marked-outline:before {
  content: "\f22b";
}

.mdi-checkbox-multiple-blank:before {
  content: "\f22c";
}

.mdi-checkbox-multiple-blank-outline:before {
  content: "\f22d";
}

.mdi-checkbox-multiple-marked:before {
  content: "\f22e";
}

.mdi-checkbox-multiple-marked-outline:before {
  content: "\f22f";
}

.mdi-checkerboard:before {
  content: "\f230";
}

.mdi-chemical-weapon:before {
  content: "\f231";
}

.mdi-chevron-double-down:before {
  content: "\f232";
}

.mdi-chevron-double-left:before {
  content: "\f233";
}

.mdi-chevron-double-right:before {
  content: "\f234";
}

.mdi-chevron-double-up:before {
  content: "\f235";
}

.mdi-chevron-down:before {
  content: "\f236";
}

.mdi-chevron-left:before {
  content: "\f237";
}

.mdi-chevron-right:before {
  content: "\f238";
}

.mdi-chevron-up:before {
  content: "\f239";
}

.mdi-church:before {
  content: "\f23a";
}

.mdi-cisco-webex:before {
  content: "\f23b";
}

.mdi-city:before {
  content: "\f23c";
}

.mdi-clipboard:before {
  content: "\f23d";
}

.mdi-clipboard-account:before {
  content: "\f23e";
}

.mdi-clipboard-alert:before {
  content: "\f23f";
}

.mdi-clipboard-arrow-down:before {
  content: "\f240";
}

.mdi-clipboard-arrow-left:before {
  content: "\f241";
}

.mdi-clipboard-check:before {
  content: "\f242";
}

.mdi-clipboard-outline:before {
  content: "\f243";
}

.mdi-clipboard-text:before {
  content: "\f244";
}

.mdi-clippy:before {
  content: "\f245";
}

.mdi-clock:before {
  content: "\f246";
}

.mdi-clock-end:before {
  content: "\f247";
}

.mdi-clock-fast:before {
  content: "\f248";
}

.mdi-clock-in:before {
  content: "\f249";
}

.mdi-clock-out:before {
  content: "\f24a";
}

.mdi-clock-start:before {
  content: "\f24b";
}

.mdi-close:before {
  content: "\f24c";
}

.mdi-close-box:before {
  content: "\f24d";
}

.mdi-close-box-outline:before {
  content: "\f24e";
}

.mdi-close-circle:before {
  content: "\f24f";
}

.mdi-close-circle-outline:before {
  content: "\f250";
}

.mdi-close-network:before {
  content: "\f251";
}

.mdi-close-octagon:before {
  content: "\f252";
}

.mdi-close-octagon-outline:before {
  content: "\f253";
}

.mdi-closed-caption:before {
  content: "\f254";
}

.mdi-cloud:before {
  content: "\f255";
}

.mdi-cloud-check:before {
  content: "\f256";
}

.mdi-cloud-circle:before {
  content: "\f257";
}

.mdi-cloud-download:before {
  content: "\f258";
}

.mdi-cloud-outline:before {
  content: "\f259";
}

.mdi-cloud-outline-off:before {
  content: "\f25a";
}

.mdi-cloud-print:before {
  content: "\f25b";
}

.mdi-cloud-print-outline:before {
  content: "\f25c";
}

.mdi-cloud-upload:before {
  content: "\f25d";
}

.mdi-code-array:before {
  content: "\f25e";
}

.mdi-code-braces:before {
  content: "\f25f";
}

.mdi-code-brackets:before {
  content: "\f260";
}

.mdi-code-equal:before {
  content: "\f261";
}

.mdi-code-greater-than:before {
  content: "\f262";
}

.mdi-code-greater-than-or-equal:before {
  content: "\f263";
}

.mdi-code-less-than:before {
  content: "\f264";
}

.mdi-code-less-than-or-equal:before {
  content: "\f265";
}

.mdi-code-not-equal:before {
  content: "\f266";
}

.mdi-code-not-equal-variant:before {
  content: "\f267";
}

.mdi-code-parentheses:before {
  content: "\f268";
}

.mdi-code-string:before {
  content: "\f269";
}

.mdi-code-tags:before {
  content: "\f26a";
}

.mdi-codepen:before {
  content: "\f26b";
}

.mdi-coffee:before {
  content: "\f26c";
}

.mdi-coffee-to-go:before {
  content: "\f26d";
}

.mdi-coin:before {
  content: "\f26e";
}

.mdi-color-helper:before {
  content: "\f26f";
}

.mdi-comment:before {
  content: "\f270";
}

.mdi-comment-account:before {
  content: "\f271";
}

.mdi-comment-account-outline:before {
  content: "\f272";
}

.mdi-comment-alert:before {
  content: "\f273";
}

.mdi-comment-alert-outline:before {
  content: "\f274";
}

.mdi-comment-check:before {
  content: "\f275";
}

.mdi-comment-check-outline:before {
  content: "\f276";
}

.mdi-comment-multiple-outline:before {
  content: "\f277";
}

.mdi-comment-outline:before {
  content: "\f278";
}

.mdi-comment-plus-outline:before {
  content: "\f279";
}

.mdi-comment-processing:before {
  content: "\f27a";
}

.mdi-comment-processing-outline:before {
  content: "\f27b";
}

.mdi-comment-question-outline:before {
  content: "\f27c";
}

.mdi-comment-remove-outline:before {
  content: "\f27d";
}

.mdi-comment-text:before {
  content: "\f27e";
}

.mdi-comment-text-outline:before {
  content: "\f27f";
}

.mdi-compare:before {
  content: "\f280";
}

.mdi-compass:before {
  content: "\f281";
}

.mdi-compass-outline:before {
  content: "\f282";
}

.mdi-console:before {
  content: "\f283";
}

.mdi-contact-mail:before {
  content: "\f284";
}

.mdi-content-copy:before {
  content: "\f285";
}

.mdi-content-cut:before {
  content: "\f286";
}

.mdi-content-duplicate:before {
  content: "\f287";
}

.mdi-content-paste:before {
  content: "\f288";
}

.mdi-content-save:before {
  content: "\f289";
}

.mdi-content-save-all:before {
  content: "\f28a";
}

.mdi-contrast:before {
  content: "\f28b";
}

.mdi-contrast-box:before {
  content: "\f28c";
}

.mdi-contrast-circle:before {
  content: "\f28d";
}

.mdi-cookie:before {
  content: "\f28e";
}

.mdi-cow:before {
  content: "\f28f";
}

.mdi-credit-card:before {
  content: "\f290";
}

.mdi-credit-card-multiple:before {
  content: "\f291";
}

.mdi-credit-card-scan:before {
  content: "\f292";
}

.mdi-crop:before {
  content: "\f293";
}

.mdi-crop-free:before {
  content: "\f294";
}

.mdi-crop-landscape:before {
  content: "\f295";
}

.mdi-crop-portrait:before {
  content: "\f296";
}

.mdi-crop-square:before {
  content: "\f297";
}

.mdi-crosshairs:before {
  content: "\f298";
}

.mdi-crosshairs-gps:before {
  content: "\f299";
}

.mdi-crown:before {
  content: "\f29a";
}

.mdi-cube:before {
  content: "\f29b";
}

.mdi-cube-outline:before {
  content: "\f29c";
}

.mdi-cube-send:before {
  content: "\f29d";
}

.mdi-cube-unfolded:before {
  content: "\f29e";
}

.mdi-cup:before {
  content: "\f29f";
}

.mdi-cup-water:before {
  content: "\f2a0";
}

.mdi-currency-btc:before {
  content: "\f2a1";
}

.mdi-currency-eur:before {
  content: "\f2a2";
}

.mdi-currency-gbp:before {
  content: "\f2a3";
}

.mdi-currency-inr:before {
  content: "\f2a4";
}

.mdi-currency-ngn:before {
  content: "\f2a5";
}

.mdi-currency-rub:before {
  content: "\f2a6";
}

.mdi-currency-try:before {
  content: "\f2a7";
}

.mdi-currency-usd:before {
  content: "\f2a8";
}

.mdi-cursor-default:before {
  content: "\f2a9";
}

.mdi-cursor-default-outline:before {
  content: "\f2aa";
}

.mdi-cursor-move:before {
  content: "\f2ab";
}

.mdi-cursor-pointer:before {
  content: "\f2ac";
}

.mdi-database:before {
  content: "\f2ad";
}

.mdi-database-minus:before {
  content: "\f2ae";
}

.mdi-database-plus:before {
  content: "\f2af";
}

.mdi-debug-step-into:before {
  content: "\f2b0";
}

.mdi-debug-step-out:before {
  content: "\f2b1";
}

.mdi-debug-step-over:before {
  content: "\f2b2";
}

.mdi-decimal-decrease:before {
  content: "\f2b3";
}

.mdi-decimal-increase:before {
  content: "\f2b4";
}

.mdi-delete:before {
  content: "\f2b5";
}

.mdi-delete-variant:before {
  content: "\f2b6";
}

.mdi-delta:before {
  content: "\f2b7";
}

.mdi-deskphone:before {
  content: "\f2b8";
}

.mdi-desktop-mac:before {
  content: "\f2b9";
}

.mdi-desktop-tower:before {
  content: "\f2ba";
}

.mdi-details:before {
  content: "\f2bb";
}

.mdi-deviantart:before {
  content: "\f2bc";
}

.mdi-diamond:before {
  content: "\f2bd";
}

.mdi-dice:before {
  content: "\f2be";
}

.mdi-dice-1:before {
  content: "\f2bf";
}

.mdi-dice-2:before {
  content: "\f2c0";
}

.mdi-dice-3:before {
  content: "\f2c1";
}

.mdi-dice-4:before {
  content: "\f2c2";
}

.mdi-dice-5:before {
  content: "\f2c3";
}

.mdi-dice-6:before {
  content: "\f2c4";
}

.mdi-directions:before {
  content: "\f2c5";
}

.mdi-disk-alert:before {
  content: "\f2c6";
}

.mdi-disqus:before {
  content: "\f2c7";
}

.mdi-disqus-outline:before {
  content: "\f2c8";
}

.mdi-division:before {
  content: "\f2c9";
}

.mdi-division-box:before {
  content: "\f2ca";
}

.mdi-dns:before {
  content: "\f2cb";
}

.mdi-domain:before {
  content: "\f2cc";
}

.mdi-dots-horizontal:before {
  content: "\f2cd";
}

.mdi-dots-vertical:before {
  content: "\f2ce";
}

.mdi-download:before {
  content: "\f2cf";
}

.mdi-drag:before {
  content: "\f2d0";
}

.mdi-drag-horizontal:before {
  content: "\f2d1";
}

.mdi-drag-vertical:before {
  content: "\f2d2";
}

.mdi-drawing:before {
  content: "\f2d3";
}

.mdi-drawing-box:before {
  content: "\f2d4";
}

.mdi-dribbble:before {
  content: "\f2d5";
}

.mdi-dribbble-box:before {
  content: "\f2d6";
}

.mdi-drone:before {
  content: "\f2d7";
}

.mdi-dropbox:before {
  content: "\f2d8";
}

.mdi-drupal:before {
  content: "\f2d9";
}

.mdi-duck:before {
  content: "\f2da";
}

.mdi-dumbbell:before {
  content: "\f2db";
}

.mdi-earth:before {
  content: "\f2dc";
}

.mdi-earth-off:before {
  content: "\f2dd";
}

.mdi-edge:before {
  content: "\f2de";
}

.mdi-eject:before {
  content: "\f2df";
}

.mdi-elevation-decline:before {
  content: "\f2e0";
}

.mdi-elevation-rise:before {
  content: "\f2e1";
}

.mdi-elevator:before {
  content: "\f2e2";
}

.mdi-email:before {
  content: "\f2e3";
}

.mdi-email-open:before {
  content: "\f2e4";
}

.mdi-email-outline:before {
  content: "\f2e5";
}

.mdi-email-secure:before {
  content: "\f2e6";
}

.mdi-emoticon:before {
  content: "\f2e7";
}

.mdi-emoticon-cool:before {
  content: "\f2e8";
}

.mdi-emoticon-devil:before {
  content: "\f2e9";
}

.mdi-emoticon-happy:before {
  content: "\f2ea";
}

.mdi-emoticon-neutral:before {
  content: "\f2eb";
}

.mdi-emoticon-poop:before {
  content: "\f2ec";
}

.mdi-emoticon-sad:before {
  content: "\f2ed";
}

.mdi-emoticon-tongue:before {
  content: "\f2ee";
}

.mdi-engine:before {
  content: "\f2ef";
}

.mdi-engine-outline:before {
  content: "\f2f0";
}

.mdi-equal:before {
  content: "\f2f1";
}

.mdi-equal-box:before {
  content: "\f2f2";
}

.mdi-eraser:before {
  content: "\f2f3";
}

.mdi-escalator:before {
  content: "\f2f4";
}

.mdi-ethernet:before {
  content: "\f2f5";
}

.mdi-ethernet-cable:before {
  content: "\f2f6";
}

.mdi-ethernet-cable-off:before {
  content: "\f2f7";
}

.mdi-etsy:before {
  content: "\f2f8";
}

.mdi-evernote:before {
  content: "\f2f9";
}

.mdi-exclamation:before {
  content: "\f2fa";
}

.mdi-exit-to-app:before {
  content: "\f2fb";
}

.mdi-export:before {
  content: "\f2fc";
}

.mdi-eye:before {
  content: "\f2fd";
}

.mdi-eye-off:before {
  content: "\f2fe";
}

.mdi-eyedropper:before {
  content: "\f2ff";
}

.mdi-eyedropper-variant:before {
  content: "\f300";
}

.mdi-facebook:before {
  content: "\f301";
}

.mdi-facebook-box:before {
  content: "\f302";
}

.mdi-facebook-messenger:before {
  content: "\f303";
}

.mdi-factory:before {
  content: "\f304";
}

.mdi-fan:before {
  content: "\f305";
}

.mdi-fast-forward:before {
  content: "\f306";
}

.mdi-fax:before {
  content: "\f307";
}

.mdi-ferry:before {
  content: "\f308";
}

.mdi-file:before {
  content: "\f309";
}

.mdi-file-chart:before {
  content: "\f30a";
}

.mdi-file-check:before {
  content: "\f30b";
}

.mdi-file-cloud:before {
  content: "\f30c";
}

.mdi-file-delimited:before {
  content: "\f30d";
}

.mdi-file-document:before {
  content: "\f30e";
}

.mdi-file-document-box:before {
  content: "\f30f";
}

.mdi-file-excel:before {
  content: "\f310";
}

.mdi-file-excel-box:before {
  content: "\f311";
}

.mdi-file-export:before {
  content: "\f312";
}

.mdi-file-find:before {
  content: "\f313";
}

.mdi-file-image:before {
  content: "\f314";
}

.mdi-file-import:before {
  content: "\f315";
}

.mdi-file-lock:before {
  content: "\f316";
}

.mdi-file-multiple:before {
  content: "\f317";
}

.mdi-file-music:before {
  content: "\f318";
}

.mdi-file-outline:before {
  content: "\f319";
}

.mdi-file-pdf:before {
  content: "\f31a";
}

.mdi-file-pdf-box:before {
  content: "\f31b";
}

.mdi-file-powerpoint:before {
  content: "\f31c";
}

.mdi-file-powerpoint-box:before {
  content: "\f31d";
}

.mdi-file-presentation-box:before {
  content: "\f31e";
}

.mdi-file-send:before {
  content: "\f31f";
}

.mdi-file-video:before {
  content: "\f320";
}

.mdi-file-word:before {
  content: "\f321";
}

.mdi-file-word-box:before {
  content: "\f322";
}

.mdi-file-xml:before {
  content: "\f323";
}

.mdi-film:before {
  content: "\f324";
}

.mdi-filmstrip:before {
  content: "\f325";
}

.mdi-filmstrip-off:before {
  content: "\f326";
}

.mdi-filter:before {
  content: "\f327";
}

.mdi-filter-outline:before {
  content: "\f328";
}

.mdi-filter-remove:before {
  content: "\f329";
}

.mdi-filter-remove-outline:before {
  content: "\f32a";
}

.mdi-filter-variant:before {
  content: "\f32b";
}

.mdi-fingerprint:before {
  content: "\f32c";
}

.mdi-fire:before {
  content: "\f32d";
}

.mdi-firefox:before {
  content: "\f32e";
}

.mdi-fish:before {
  content: "\f32f";
}

.mdi-flag:before {
  content: "\f330";
}

.mdi-flag-checkered:before {
  content: "\f331";
}

.mdi-flag-outline:before {
  content: "\f332";
}

.mdi-flag-outline-variant:before {
  content: "\f333";
}

.mdi-flag-triangle:before {
  content: "\f334";
}

.mdi-flag-variant:before {
  content: "\f335";
}

.mdi-flash:before {
  content: "\f336";
}

.mdi-flash-auto:before {
  content: "\f337";
}

.mdi-flash-off:before {
  content: "\f338";
}

.mdi-flashlight:before {
  content: "\f339";
}

.mdi-flashlight-off:before {
  content: "\f33a";
}

.mdi-flattr:before {
  content: "\f33b";
}

.mdi-flip-to-back:before {
  content: "\f33c";
}

.mdi-flip-to-front:before {
  content: "\f33d";
}

.mdi-floppy:before {
  content: "\f33e";
}

.mdi-flower:before {
  content: "\f33f";
}

.mdi-folder:before {
  content: "\f340";
}

.mdi-folder-account:before {
  content: "\f341";
}

.mdi-folder-download:before {
  content: "\f342";
}

.mdi-folder-google-drive:before {
  content: "\f343";
}

.mdi-folder-image:before {
  content: "\f344";
}

.mdi-folder-lock:before {
  content: "\f345";
}

.mdi-folder-lock-open:before {
  content: "\f346";
}

.mdi-folder-move:before {
  content: "\f347";
}

.mdi-folder-multiple:before {
  content: "\f348";
}

.mdi-folder-multiple-image:before {
  content: "\f349";
}

.mdi-folder-multiple-outline:before {
  content: "\f34a";
}

.mdi-folder-outline:before {
  content: "\f34b";
}

.mdi-folder-plus:before {
  content: "\f34c";
}

.mdi-folder-remove:before {
  content: "\f34d";
}

.mdi-folder-upload:before {
  content: "\f34e";
}

.mdi-food:before {
  content: "\f34f";
}

.mdi-food-apple:before {
  content: "\f350";
}

.mdi-food-variant:before {
  content: "\f351";
}

.mdi-football:before {
  content: "\f352";
}

.mdi-football-australian:before {
  content: "\f353";
}

.mdi-football-helmet:before {
  content: "\f354";
}

.mdi-format-align-center:before {
  content: "\f355";
}

.mdi-format-align-justify:before {
  content: "\f356";
}

.mdi-format-align-left:before {
  content: "\f357";
}

.mdi-format-align-right:before {
  content: "\f358";
}

.mdi-format-bold:before {
  content: "\f359";
}

.mdi-format-clear:before {
  content: "\f35a";
}

.mdi-format-color-fill:before {
  content: "\f35b";
}

.mdi-format-float-center:before {
  content: "\f35c";
}

.mdi-format-float-left:before {
  content: "\f35d";
}

.mdi-format-float-none:before {
  content: "\f35e";
}

.mdi-format-float-right:before {
  content: "\f35f";
}

.mdi-format-header-1:before {
  content: "\f360";
}

.mdi-format-header-2:before {
  content: "\f361";
}

.mdi-format-header-3:before {
  content: "\f362";
}

.mdi-format-header-4:before {
  content: "\f363";
}

.mdi-format-header-5:before {
  content: "\f364";
}

.mdi-format-header-6:before {
  content: "\f365";
}

.mdi-format-header-decrease:before {
  content: "\f366";
}

.mdi-format-header-equal:before {
  content: "\f367";
}

.mdi-format-header-increase:before {
  content: "\f368";
}

.mdi-format-header-pound:before {
  content: "\f369";
}

.mdi-format-indent-decrease:before {
  content: "\f36a";
}

.mdi-format-indent-increase:before {
  content: "\f36b";
}

.mdi-format-italic:before {
  content: "\f36c";
}

.mdi-format-line-spacing:before {
  content: "\f36d";
}

.mdi-format-list-bulleted:before {
  content: "\f36e";
}

.mdi-format-list-bulleted-type:before {
  content: "\f36f";
}

.mdi-format-list-numbers:before {
  content: "\f370";
}

.mdi-format-paint:before {
  content: "\f371";
}

.mdi-format-paragraph:before {
  content: "\f372";
}

.mdi-format-quote:before {
  content: "\f373";
}

.mdi-format-size:before {
  content: "\f374";
}

.mdi-format-strikethrough:before {
  content: "\f375";
}

.mdi-format-strikethrough-variant:before {
  content: "\f376";
}

.mdi-format-subscript:before {
  content: "\f377";
}

.mdi-format-superscript:before {
  content: "\f378";
}

.mdi-format-text:before {
  content: "\f379";
}

.mdi-format-textdirection-l-to-r:before {
  content: "\f37a";
}

.mdi-format-textdirection-r-to-l:before {
  content: "\f37b";
}

.mdi-format-underline:before {
  content: "\f37c";
}

.mdi-format-wrap-inline:before {
  content: "\f37d";
}

.mdi-format-wrap-square:before {
  content: "\f37e";
}

.mdi-format-wrap-tight:before {
  content: "\f37f";
}

.mdi-format-wrap-top-bottom:before {
  content: "\f380";
}

.mdi-forum:before {
  content: "\f381";
}

.mdi-forward:before {
  content: "\f382";
}

.mdi-foursquare:before {
  content: "\f383";
}

.mdi-fridge:before {
  content: "\f384";
}

.mdi-fridge-filled:before {
  content: "\f385";
}

.mdi-fridge-filled-bottom:before {
  content: "\f386";
}

.mdi-fridge-filled-top:before {
  content: "\f387";
}

.mdi-fullscreen:before {
  content: "\f388";
}

.mdi-fullscreen-exit:before {
  content: "\f389";
}

.mdi-function:before {
  content: "\f38a";
}

.mdi-gamepad:before {
  content: "\f38b";
}

.mdi-gamepad-variant:before {
  content: "\f38c";
}

.mdi-gas-station:before {
  content: "\f38d";
}

.mdi-gate:before {
  content: "\f38e";
}

.mdi-gauge:before {
  content: "\f38f";
}

.mdi-gavel:before {
  content: "\f390";
}

.mdi-gender-female:before {
  content: "\f391";
}

.mdi-gender-male:before {
  content: "\f392";
}

.mdi-gender-male-female:before {
  content: "\f393";
}

.mdi-gender-transgender:before {
  content: "\f394";
}

.mdi-ghost:before {
  content: "\f395";
}

.mdi-gift:before {
  content: "\f396";
}

.mdi-git:before {
  content: "\f397";
}

.mdi-github-box:before {
  content: "\f398";
}

.mdi-github-circle:before {
  content: "\f399";
}

.mdi-glass-flute:before {
  content: "\f39a";
}

.mdi-glass-mug:before {
  content: "\f39b";
}

.mdi-glass-stange:before {
  content: "\f39c";
}

.mdi-glass-tulip:before {
  content: "\f39d";
}

.mdi-glasses:before {
  content: "\f39e";
}

.mdi-gmail:before {
  content: "\f39f";
}

.mdi-google:before {
  content: "\f3a0";
}

.mdi-google-cardboard:before {
  content: "\f3a1";
}

.mdi-google-chrome:before {
  content: "\f3a2";
}

.mdi-google-circles:before {
  content: "\f3a3";
}

.mdi-google-circles-communities:before {
  content: "\f3a4";
}

.mdi-google-circles-extended:before {
  content: "\f3a5";
}

.mdi-google-circles-group:before {
  content: "\f3a6";
}

.mdi-google-controller:before {
  content: "\f3a7";
}

.mdi-google-controller-off:before {
  content: "\f3a8";
}

.mdi-google-drive:before {
  content: "\f3a9";
}

.mdi-google-earth:before {
  content: "\f3aa";
}

.mdi-google-glass:before {
  content: "\f3ab";
}

.mdi-google-nearby:before {
  content: "\f3ac";
}

.mdi-google-pages:before {
  content: "\f3ad";
}

.mdi-google-physical-web:before {
  content: "\f3ae";
}

.mdi-google-play:before {
  content: "\f3af";
}

.mdi-google-plus:before {
  content: "\f3b0";
}

.mdi-google-plus-box:before {
  content: "\f3b1";
}

.mdi-google-translate:before {
  content: "\f3b2";
}

.mdi-google-wallet:before {
  content: "\f3b3";
}

.mdi-grid:before {
  content: "\f3b4";
}

.mdi-grid-off:before {
  content: "\f3b5";
}

.mdi-group:before {
  content: "\f3b6";
}

.mdi-guitar:before {
  content: "\f3b7";
}

.mdi-guitar-pick:before {
  content: "\f3b8";
}

.mdi-guitar-pick-outline:before {
  content: "\f3b9";
}

.mdi-hand-pointing-right:before {
  content: "\f3ba";
}

.mdi-hanger:before {
  content: "\f3bb";
}

.mdi-hangouts:before {
  content: "\f3bc";
}

.mdi-harddisk:before {
  content: "\f3bd";
}

.mdi-headphones:before {
  content: "\f3be";
}

.mdi-headphones-box:before {
  content: "\f3bf";
}

.mdi-headphones-settings:before {
  content: "\f3c0";
}

.mdi-headset:before {
  content: "\f3c1";
}

.mdi-headset-dock:before {
  content: "\f3c2";
}

.mdi-headset-off:before {
  content: "\f3c3";
}

.mdi-heart:before {
  content: "\f3c4";
}

.mdi-heart-box:before {
  content: "\f3c5";
}

.mdi-heart-box-outline:before {
  content: "\f3c6";
}

.mdi-heart-broken:before {
  content: "\f3c7";
}

.mdi-heart-outline:before {
  content: "\f3c8";
}

.mdi-help:before {
  content: "\f3c9";
}

.mdi-help-circle:before {
  content: "\f3ca";
}

.mdi-hexagon:before {
  content: "\f3cb";
}

.mdi-hexagon-outline:before {
  content: "\f3cc";
}

.mdi-history:before {
  content: "\f3cd";
}

.mdi-hololens:before {
  content: "\f3ce";
}

.mdi-home:before {
  content: "\f3cf";
}

.mdi-home-modern:before {
  content: "\f3d0";
}

.mdi-home-variant:before {
  content: "\f3d1";
}

.mdi-hops:before {
  content: "\f3d2";
}

.mdi-hospital:before {
  content: "\f3d3";
}

.mdi-hospital-building:before {
  content: "\f3d4";
}

.mdi-hospital-marker:before {
  content: "\f3d5";
}

.mdi-hotel:before {
  content: "\f3d6";
}

.mdi-houzz:before {
  content: "\f3d7";
}

.mdi-houzz-box:before {
  content: "\f3d8";
}

.mdi-human:before {
  content: "\f3d9";
}

.mdi-human-child:before {
  content: "\f3da";
}

.mdi-human-male-female:before {
  content: "\f3db";
}

.mdi-image:before {
  content: "\f3dc";
}

.mdi-image-album:before {
  content: "\f3dd";
}

.mdi-image-area:before {
  content: "\f3de";
}

.mdi-image-area-close:before {
  content: "\f3df";
}

.mdi-image-broken:before {
  content: "\f3e0";
}

.mdi-image-broken-variant:before {
  content: "\f3e1";
}

.mdi-image-filter:before {
  content: "\f3e2";
}

.mdi-image-filter-black-white:before {
  content: "\f3e3";
}

.mdi-image-filter-center-focus:before {
  content: "\f3e4";
}

.mdi-image-filter-center-focus-weak:before {
  content: "\f3e5";
}

.mdi-image-filter-drama:before {
  content: "\f3e6";
}

.mdi-image-filter-frames:before {
  content: "\f3e7";
}

.mdi-image-filter-hdr:before {
  content: "\f3e8";
}

.mdi-image-filter-none:before {
  content: "\f3e9";
}

.mdi-image-filter-tilt-shift:before {
  content: "\f3ea";
}

.mdi-image-filter-vintage:before {
  content: "\f3eb";
}

.mdi-image-multiple:before {
  content: "\f3ec";
}

.mdi-import:before {
  content: "\f3ed";
}

.mdi-inbox:before {
  content: "\f3ee";
}

.mdi-information:before {
  content: "\f3ef";
}

.mdi-information-outline:before {
  content: "\f3f0";
}

.mdi-instagram:before {
  content: "\f3f1";
}

.mdi-instapaper:before {
  content: "\f3f2";
}

.mdi-internet-explorer:before {
  content: "\f3f3";
}

.mdi-invert-colors:before {
  content: "\f3f4";
}

.mdi-jeepney:before {
  content: "\f3f5";
}

.mdi-jira:before {
  content: "\f3f6";
}

.mdi-jsfiddle:before {
  content: "\f3f7";
}

.mdi-keg:before {
  content: "\f3f8";
}

.mdi-key:before {
  content: "\f3f9";
}

.mdi-key-change:before {
  content: "\f3fa";
}

.mdi-key-minus:before {
  content: "\f3fb";
}

.mdi-key-plus:before {
  content: "\f3fc";
}

.mdi-key-remove:before {
  content: "\f3fd";
}

.mdi-key-variant:before {
  content: "\f3fe";
}

.mdi-keyboard:before {
  content: "\f3ff";
}

.mdi-keyboard-backspace:before {
  content: "\f400";
}

.mdi-keyboard-caps:before {
  content: "\f401";
}

.mdi-keyboard-close:before {
  content: "\f402";
}

.mdi-keyboard-off:before {
  content: "\f403";
}

.mdi-keyboard-return:before {
  content: "\f404";
}

.mdi-keyboard-tab:before {
  content: "\f405";
}

.mdi-keyboard-variant:before {
  content: "\f406";
}

.mdi-label:before {
  content: "\f407";
}

.mdi-label-outline:before {
  content: "\f408";
}

.mdi-lan:before {
  content: "\f409";
}

.mdi-lan-connect:before {
  content: "\f40a";
}

.mdi-lan-disconnect:before {
  content: "\f40b";
}

.mdi-lan-pending:before {
  content: "\f40c";
}

.mdi-language-csharp:before {
  content: "\f40d";
}

.mdi-language-css3:before {
  content: "\f40e";
}

.mdi-language-html5:before {
  content: "\f40f";
}

.mdi-language-javascript:before {
  content: "\f410";
}

.mdi-language-php:before {
  content: "\f411";
}

.mdi-language-python:before {
  content: "\f412";
}

.mdi-language-python-text:before {
  content: "\f413";
}

.mdi-laptop:before {
  content: "\f414";
}

.mdi-laptop-chromebook:before {
  content: "\f415";
}

.mdi-laptop-mac:before {
  content: "\f416";
}

.mdi-laptop-windows:before {
  content: "\f417";
}

.mdi-lastfm:before {
  content: "\f418";
}

.mdi-launch:before {
  content: "\f419";
}

.mdi-layers:before {
  content: "\f41a";
}

.mdi-layers-off:before {
  content: "\f41b";
}

.mdi-leaf:before {
  content: "\f41c";
}

.mdi-led-off:before {
  content: "\f41d";
}

.mdi-led-on:before {
  content: "\f41e";
}

.mdi-led-outline:before {
  content: "\f41f";
}

.mdi-led-variant-off:before {
  content: "\f420";
}

.mdi-led-variant-on:before {
  content: "\f421";
}

.mdi-led-variant-outline:before {
  content: "\f422";
}

.mdi-library:before {
  content: "\f423";
}

.mdi-library-books:before {
  content: "\f424";
}

.mdi-library-music:before {
  content: "\f425";
}

.mdi-library-plus:before {
  content: "\f426";
}

.mdi-lightbulb:before {
  content: "\f427";
}

.mdi-lightbulb-outline:before {
  content: "\f428";
}

.mdi-link:before {
  content: "\f429";
}

.mdi-link-off:before {
  content: "\f42a";
}

.mdi-link-variant:before {
  content: "\f42b";
}

.mdi-link-variant-off:before {
  content: "\f42c";
}

.mdi-linkedin:before {
  content: "\f42d";
}

.mdi-linkedin-box:before {
  content: "\f42e";
}

.mdi-linux:before {
  content: "\f42f";
}

.mdi-lock:before {
  content: "\f430";
}

.mdi-lock-open:before {
  content: "\f431";
}

.mdi-lock-open-outline:before {
  content: "\f432";
}

.mdi-lock-outline:before {
  content: "\f433";
}

.mdi-login:before {
  content: "\f434";
}

.mdi-logout:before {
  content: "\f435";
}

.mdi-looks:before {
  content: "\f436";
}

.mdi-loupe:before {
  content: "\f437";
}

.mdi-lumx:before {
  content: "\f438";
}

.mdi-magnet:before {
  content: "\f439";
}

.mdi-magnet-on:before {
  content: "\f43a";
}

.mdi-magnify:before {
  content: "\f43b";
}

.mdi-magnify-minus:before {
  content: "\f43c";
}

.mdi-magnify-plus:before {
  content: "\f43d";
}

.mdi-mail-ru:before {
  content: "\f43e";
}

.mdi-map:before {
  content: "\f43f";
}

.mdi-map-marker:before {
  content: "\f440";
}

.mdi-map-marker-circle:before {
  content: "\f441";
}

.mdi-map-marker-multiple:before {
  content: "\f442";
}

.mdi-map-marker-off:before {
  content: "\f443";
}

.mdi-map-marker-radius:before {
  content: "\f444";
}

.mdi-margin:before {
  content: "\f445";
}

.mdi-markdown:before {
  content: "\f446";
}

.mdi-marker-check:before {
  content: "\f447";
}

.mdi-martini:before {
  content: "\f448";
}

.mdi-material-ui:before {
  content: "\f449";
}

.mdi-math-compass:before {
  content: "\f44a";
}

.mdi-maxcdn:before {
  content: "\f44b";
}

.mdi-medium:before {
  content: "\f44c";
}

.mdi-memory:before {
  content: "\f44d";
}

.mdi-menu:before {
  content: "\f44e";
}

.mdi-menu-down:before {
  content: "\f44f";
}

.mdi-menu-left:before {
  content: "\f450";
}

.mdi-menu-right:before {
  content: "\f451";
}

.mdi-menu-up:before {
  content: "\f452";
}

.mdi-message:before {
  content: "\f453";
}

.mdi-message-alert:before {
  content: "\f454";
}

.mdi-message-draw:before {
  content: "\f455";
}

.mdi-message-image:before {
  content: "\f456";
}

.mdi-message-outline:before {
  content: "\f457";
}

.mdi-message-processing:before {
  content: "\f458";
}

.mdi-message-reply:before {
  content: "\f459";
}

.mdi-message-reply-text:before {
  content: "\f45a";
}

.mdi-message-text:before {
  content: "\f45b";
}

.mdi-message-text-outline:before {
  content: "\f45c";
}

.mdi-message-video:before {
  content: "\f45d";
}

.mdi-microphone:before {
  content: "\f45e";
}

.mdi-microphone-off:before {
  content: "\f45f";
}

.mdi-microphone-outline:before {
  content: "\f460";
}

.mdi-microphone-settings:before {
  content: "\f461";
}

.mdi-microphone-variant:before {
  content: "\f462";
}

.mdi-microphone-variant-off:before {
  content: "\f463";
}

.mdi-microsoft:before {
  content: "\f464";
}

.mdi-minus:before {
  content: "\f465";
}

.mdi-minus-box:before {
  content: "\f466";
}

.mdi-minus-circle:before {
  content: "\f467";
}

.mdi-minus-circle-outline:before {
  content: "\f468";
}

.mdi-minus-network:before {
  content: "\f469";
}

.mdi-monitor:before {
  content: "\f46a";
}

.mdi-monitor-multiple:before {
  content: "\f46b";
}

.mdi-more:before {
  content: "\f46c";
}

.mdi-motorbike:before {
  content: "\f46d";
}

.mdi-mouse:before {
  content: "\f46e";
}

.mdi-mouse-off:before {
  content: "\f46f";
}

.mdi-mouse-variant:before {
  content: "\f470";
}

.mdi-mouse-variant-off:before {
  content: "\f471";
}

.mdi-movie:before {
  content: "\f472";
}

.mdi-multiplication:before {
  content: "\f473";
}

.mdi-multiplication-box:before {
  content: "\f474";
}

.mdi-music-box:before {
  content: "\f475";
}

.mdi-music-box-outline:before {
  content: "\f476";
}

.mdi-music-circle:before {
  content: "\f477";
}

.mdi-music-note:before {
  content: "\f478";
}

.mdi-music-note-eighth:before {
  content: "\f479";
}

.mdi-music-note-half:before {
  content: "\f47a";
}

.mdi-music-note-off:before {
  content: "\f47b";
}

.mdi-music-note-quarter:before {
  content: "\f47c";
}

.mdi-music-note-sixteenth:before {
  content: "\f47d";
}

.mdi-music-note-whole:before {
  content: "\f47e";
}

.mdi-nature:before {
  content: "\f47f";
}

.mdi-nature-people:before {
  content: "\f480";
}

.mdi-navigation:before {
  content: "\f481";
}

.mdi-needle:before {
  content: "\f482";
}

.mdi-nest-protect:before {
  content: "\f483";
}

.mdi-nest-thermostat:before {
  content: "\f484";
}

.mdi-newspaper:before {
  content: "\f485";
}

.mdi-nfc:before {
  content: "\f486";
}

.mdi-nfc-tap:before {
  content: "\f487";
}

.mdi-nfc-variant:before {
  content: "\f488";
}

.mdi-nodejs:before {
  content: "\f489";
}

.mdi-note:before {
  content: "\f48a";
}

.mdi-note-outline:before {
  content: "\f48b";
}

.mdi-note-plus:before {
  content: "\f48c";
}

.mdi-note-plus-outline:before {
  content: "\f48d";
}

.mdi-note-text:before {
  content: "\f48e";
}

.mdi-notification-clear-all:before {
  content: "\f48f";
}

.mdi-numeric:before {
  content: "\f490";
}

.mdi-numeric-0-box:before {
  content: "\f491";
}

.mdi-numeric-0-box-multiple-outline:before {
  content: "\f492";
}

.mdi-numeric-0-box-outline:before {
  content: "\f493";
}

.mdi-numeric-1-box:before {
  content: "\f494";
}

.mdi-numeric-1-box-multiple-outline:before {
  content: "\f495";
}

.mdi-numeric-1-box-outline:before {
  content: "\f496";
}

.mdi-numeric-2-box:before {
  content: "\f497";
}

.mdi-numeric-2-box-multiple-outline:before {
  content: "\f498";
}

.mdi-numeric-2-box-outline:before {
  content: "\f499";
}

.mdi-numeric-3-box:before {
  content: "\f49a";
}

.mdi-numeric-3-box-multiple-outline:before {
  content: "\f49b";
}

.mdi-numeric-3-box-outline:before {
  content: "\f49c";
}

.mdi-numeric-4-box:before {
  content: "\f49d";
}

.mdi-numeric-4-box-multiple-outline:before {
  content: "\f49e";
}

.mdi-numeric-4-box-outline:before {
  content: "\f49f";
}

.mdi-numeric-5-box:before {
  content: "\f4a0";
}

.mdi-numeric-5-box-multiple-outline:before {
  content: "\f4a1";
}

.mdi-numeric-5-box-outline:before {
  content: "\f4a2";
}

.mdi-numeric-6-box:before {
  content: "\f4a3";
}

.mdi-numeric-6-box-multiple-outline:before {
  content: "\f4a4";
}

.mdi-numeric-6-box-outline:before {
  content: "\f4a5";
}

.mdi-numeric-7-box:before {
  content: "\f4a6";
}

.mdi-numeric-7-box-multiple-outline:before {
  content: "\f4a7";
}

.mdi-numeric-7-box-outline:before {
  content: "\f4a8";
}

.mdi-numeric-8-box:before {
  content: "\f4a9";
}

.mdi-numeric-8-box-multiple-outline:before {
  content: "\f4aa";
}

.mdi-numeric-8-box-outline:before {
  content: "\f4ab";
}

.mdi-numeric-9-box:before {
  content: "\f4ac";
}

.mdi-numeric-9-box-multiple-outline:before {
  content: "\f4ad";
}

.mdi-numeric-9-box-outline:before {
  content: "\f4ae";
}

.mdi-numeric-9-plus-box:before {
  content: "\f4af";
}

.mdi-numeric-9-plus-box-multiple-outline:before {
  content: "\f4b0";
}

.mdi-numeric-9-plus-box-outline:before {
  content: "\f4b1";
}

.mdi-nutrition:before {
  content: "\f4b2";
}

.mdi-octagon:before {
  content: "\f4b3";
}

.mdi-octagon-outline:before {
  content: "\f4b4";
}

.mdi-odnoklassniki:before {
  content: "\f4b5";
}

.mdi-office:before {
  content: "\f4b6";
}

.mdi-oil:before {
  content: "\f4b7";
}

.mdi-oil-temperature:before {
  content: "\f4b8";
}

.mdi-omega:before {
  content: "\f4b9";
}

.mdi-onedrive:before {
  content: "\f4ba";
}

.mdi-open-in-app:before {
  content: "\f4bb";
}

.mdi-open-in-new:before {
  content: "\f4bc";
}

.mdi-opera:before {
  content: "\f4bd";
}

.mdi-ornament:before {
  content: "\f4be";
}

.mdi-ornament-variant:before {
  content: "\f4bf";
}

.mdi-outbox:before {
  content: "\f4c0";
}

.mdi-owl:before {
  content: "\f4c1";
}

.mdi-package:before {
  content: "\f4c2";
}

.mdi-package-down:before {
  content: "\f4c3";
}

.mdi-package-up:before {
  content: "\f4c4";
}

.mdi-package-variant:before {
  content: "\f4c5";
}

.mdi-package-variant-closed:before {
  content: "\f4c6";
}

.mdi-palette:before {
  content: "\f4c7";
}

.mdi-palette-advanced:before {
  content: "\f4c8";
}

.mdi-panda:before {
  content: "\f4c9";
}

.mdi-pandora:before {
  content: "\f4ca";
}

.mdi-panorama:before {
  content: "\f4cb";
}

.mdi-panorama-fisheye:before {
  content: "\f4cc";
}

.mdi-panorama-horizontal:before {
  content: "\f4cd";
}

.mdi-panorama-vertical:before {
  content: "\f4ce";
}

.mdi-panorama-wide-angle:before {
  content: "\f4cf";
}

.mdi-paper-cut-vertical:before {
  content: "\f4d0";
}

.mdi-paperclip:before {
  content: "\f4d1";
}

.mdi-parking:before {
  content: "\f4d2";
}

.mdi-pause:before {
  content: "\f4d3";
}

.mdi-pause-circle:before {
  content: "\f4d4";
}

.mdi-pause-circle-outline:before {
  content: "\f4d5";
}

.mdi-pause-octagon:before {
  content: "\f4d6";
}

.mdi-pause-octagon-outline:before {
  content: "\f4d7";
}

.mdi-paw:before {
  content: "\f4d8";
}

.mdi-pen:before {
  content: "\f4d9";
}

.mdi-pencil:before {
  content: "\f4da";
}

.mdi-pencil-box:before {
  content: "\f4db";
}

.mdi-pencil-box-outline:before {
  content: "\f4dc";
}

.mdi-pencil-lock:before {
  content: "\f4dd";
}

.mdi-pencil-off:before {
  content: "\f4de";
}

.mdi-percent:before {
  content: "\f4df";
}

.mdi-pharmacy:before {
  content: "\f4e0";
}

.mdi-phone:before {
  content: "\f4e1";
}

.mdi-phone-bluetooth:before {
  content: "\f4e2";
}

.mdi-phone-forward:before {
  content: "\f4e3";
}

.mdi-phone-hangup:before {
  content: "\f4e4";
}

.mdi-phone-in-talk:before {
  content: "\f4e5";
}

.mdi-phone-incoming:before {
  content: "\f4e6";
}

.mdi-phone-locked:before {
  content: "\f4e7";
}

.mdi-phone-log:before {
  content: "\f4e8";
}

.mdi-phone-missed:before {
  content: "\f4e9";
}

.mdi-phone-outgoing:before {
  content: "\f4ea";
}

.mdi-phone-paused:before {
  content: "\f4eb";
}

.mdi-phone-settings:before {
  content: "\f4ec";
}

.mdi-phone-voip:before {
  content: "\f4ed";
}

.mdi-pi:before {
  content: "\f4ee";
}

.mdi-pi-box:before {
  content: "\f4ef";
}

.mdi-pig:before {
  content: "\f4f0";
}

.mdi-pill:before {
  content: "\f4f1";
}

.mdi-pin:before {
  content: "\f4f2";
}

.mdi-pin-off:before {
  content: "\f4f3";
}

.mdi-pine-tree:before {
  content: "\f4f4";
}

.mdi-pine-tree-box:before {
  content: "\f4f5";
}

.mdi-pinterest:before {
  content: "\f4f6";
}

.mdi-pinterest-box:before {
  content: "\f4f7";
}

.mdi-pizza:before {
  content: "\f4f8";
}

.mdi-play:before {
  content: "\f4f9";
}

.mdi-play-box-outline:before {
  content: "\f4fa";
}

.mdi-play-circle:before {
  content: "\f4fb";
}

.mdi-play-circle-outline:before {
  content: "\f4fc";
}

.mdi-play-pause:before {
  content: "\f4fd";
}

.mdi-play-protected-content:before {
  content: "\f4fe";
}

.mdi-playlist-minus:before {
  content: "\f4ff";
}

.mdi-playlist-play:before {
  content: "\f500";
}

.mdi-playlist-plus:before {
  content: "\f501";
}

.mdi-playlist-remove:before {
  content: "\f502";
}

.mdi-playstation:before {
  content: "\f503";
}

.mdi-plus:before {
  content: "\f504";
}

.mdi-plus-box:before {
  content: "\f505";
}

.mdi-plus-circle:before {
  content: "\f506";
}

.mdi-plus-circle-multiple-outline:before {
  content: "\f507";
}

.mdi-plus-circle-outline:before {
  content: "\f508";
}

.mdi-plus-network:before {
  content: "\f509";
}

.mdi-plus-one:before {
  content: "\f50a";
}

.mdi-pocket:before {
  content: "\f50b";
}

.mdi-pokeball:before {
  content: "\f50c";
}

.mdi-polaroid:before {
  content: "\f50d";
}

.mdi-poll:before {
  content: "\f50e";
}

.mdi-poll-box:before {
  content: "\f50f";
}

.mdi-polymer:before {
  content: "\f510";
}

.mdi-popcorn:before {
  content: "\f511";
}

.mdi-pound:before {
  content: "\f512";
}

.mdi-pound-box:before {
  content: "\f513";
}

.mdi-power:before {
  content: "\f514";
}

.mdi-power-settings:before {
  content: "\f515";
}

.mdi-power-socket:before {
  content: "\f516";
}

.mdi-presentation:before {
  content: "\f517";
}

.mdi-presentation-play:before {
  content: "\f518";
}

.mdi-printer:before {
  content: "\f519";
}

.mdi-printer-3d:before {
  content: "\f51a";
}

.mdi-printer-alert:before {
  content: "\f51b";
}

.mdi-professional-hexagon:before {
  content: "\f51c";
}

.mdi-projector:before {
  content: "\f51d";
}

.mdi-projector-screen:before {
  content: "\f51e";
}

.mdi-pulse:before {
  content: "\f51f";
}

.mdi-puzzle:before {
  content: "\f520";
}

.mdi-qrcode:before {
  content: "\f521";
}

.mdi-qrcode-scan:before {
  content: "\f522";
}

.mdi-quadcopter:before {
  content: "\f523";
}

.mdi-quality-high:before {
  content: "\f524";
}

.mdi-quicktime:before {
  content: "\f525";
}

.mdi-radar:before {
  content: "\f526";
}

.mdi-radiator:before {
  content: "\f527";
}

.mdi-radio:before {
  content: "\f528";
}

.mdi-radio-handheld:before {
  content: "\f529";
}

.mdi-radio-tower:before {
  content: "\f52a";
}

.mdi-radioactive:before {
  content: "\f52b";
}

.mdi-radiobox-blank:before {
  content: "\f52c";
}

.mdi-radiobox-marked:before {
  content: "\f52d";
}

.mdi-raspberrypi:before {
  content: "\f52e";
}

.mdi-ray-end:before {
  content: "\f52f";
}

.mdi-ray-end-arrow:before {
  content: "\f530";
}

.mdi-ray-start:before {
  content: "\f531";
}

.mdi-ray-start-arrow:before {
  content: "\f532";
}

.mdi-ray-start-end:before {
  content: "\f533";
}

.mdi-ray-vertex:before {
  content: "\f534";
}

.mdi-rdio:before {
  content: "\f535";
}

.mdi-read:before {
  content: "\f536";
}

.mdi-readability:before {
  content: "\f537";
}

.mdi-receipt:before {
  content: "\f538";
}

.mdi-record:before {
  content: "\f539";
}

.mdi-record-rec:before {
  content: "\f53a";
}

.mdi-recycle:before {
  content: "\f53b";
}

.mdi-reddit:before {
  content: "\f53c";
}

.mdi-redo:before {
  content: "\f53d";
}

.mdi-redo-variant:before {
  content: "\f53e";
}

.mdi-refresh:before {
  content: "\f53f";
}

.mdi-regex:before {
  content: "\f540";
}

.mdi-relative-scale:before {
  content: "\f541";
}

.mdi-reload:before {
  content: "\f542";
}

.mdi-remote:before {
  content: "\f543";
}

.mdi-rename-box:before {
  content: "\f544";
}

.mdi-repeat:before {
  content: "\f545";
}

.mdi-repeat-off:before {
  content: "\f546";
}

.mdi-repeat-once:before {
  content: "\f547";
}

.mdi-replay:before {
  content: "\f548";
}

.mdi-reply:before {
  content: "\f549";
}

.mdi-reply-all:before {
  content: "\f54a";
}

.mdi-reproduction:before {
  content: "\f54b";
}

.mdi-resize-bottom-right:before {
  content: "\f54c";
}

.mdi-responsive:before {
  content: "\f54d";
}

.mdi-rewind:before {
  content: "\f54e";
}

.mdi-ribbon:before {
  content: "\f54f";
}

.mdi-road:before {
  content: "\f550";
}

.mdi-road-variant:before {
  content: "\f551";
}

.mdi-rocket:before {
  content: "\f552";
}

.mdi-rotate-3d:before {
  content: "\f553";
}

.mdi-rotate-left:before {
  content: "\f554";
}

.mdi-rotate-left-variant:before {
  content: "\f555";
}

.mdi-rotate-right:before {
  content: "\f556";
}

.mdi-rotate-right-variant:before {
  content: "\f557";
}

.mdi-router-wireless:before {
  content: "\f558";
}

.mdi-routes:before {
  content: "\f559";
}

.mdi-rss:before {
  content: "\f55a";
}

.mdi-rss-box:before {
  content: "\f55b";
}

.mdi-ruler:before {
  content: "\f55c";
}

.mdi-run:before {
  content: "\f55d";
}

.mdi-sale:before {
  content: "\f55e";
}

.mdi-satellite:before {
  content: "\f55f";
}

.mdi-satellite-variant:before {
  content: "\f560";
}

.mdi-scale:before {
  content: "\f561";
}

.mdi-scale-bathroom:before {
  content: "\f562";
}

.mdi-school:before {
  content: "\f563";
}

.mdi-screen-rotation:before {
  content: "\f564";
}

.mdi-screen-rotation-lock:before {
  content: "\f565";
}

.mdi-screwdriver:before {
  content: "\f566";
}

.mdi-script:before {
  content: "\f567";
}

.mdi-sd:before {
  content: "\f568";
}

.mdi-seal:before {
  content: "\f569";
}

.mdi-seat-flat:before {
  content: "\f56a";
}

.mdi-seat-flat-angled:before {
  content: "\f56b";
}

.mdi-seat-individual-suite:before {
  content: "\f56c";
}

.mdi-seat-legroom-extra:before {
  content: "\f56d";
}

.mdi-seat-legroom-normal:before {
  content: "\f56e";
}

.mdi-seat-legroom-reduced:before {
  content: "\f56f";
}

.mdi-seat-recline-extra:before {
  content: "\f570";
}

.mdi-seat-recline-normal:before {
  content: "\f571";
}

.mdi-security:before {
  content: "\f572";
}

.mdi-security-network:before {
  content: "\f573";
}

.mdi-select:before {
  content: "\f574";
}

.mdi-select-all:before {
  content: "\f575";
}

.mdi-select-inverse:before {
  content: "\f576";
}

.mdi-select-off:before {
  content: "\f577";
}

.mdi-selection:before {
  content: "\f578";
}

.mdi-send:before {
  content: "\f579";
}

.mdi-server:before {
  content: "\f57a";
}

.mdi-server-minus:before {
  content: "\f57b";
}

.mdi-server-network:before {
  content: "\f57c";
}

.mdi-server-network-off:before {
  content: "\f57d";
}

.mdi-server-off:before {
  content: "\f57e";
}

.mdi-server-plus:before {
  content: "\f57f";
}

.mdi-server-remove:before {
  content: "\f580";
}

.mdi-server-security:before {
  content: "\f581";
}

.mdi-settings:before {
  content: "\f582";
}

.mdi-settings-box:before {
  content: "\f583";
}

.mdi-shape-plus:before {
  content: "\f584";
}

.mdi-share:before {
  content: "\f585";
}

.mdi-share-variant:before {
  content: "\f586";
}

.mdi-shield:before {
  content: "\f587";
}

.mdi-shield-outline:before {
  content: "\f588";
}

.mdi-shopping:before {
  content: "\f589";
}

.mdi-shopping-music:before {
  content: "\f58a";
}

.mdi-shredder:before {
  content: "\f58b";
}

.mdi-shuffle:before {
  content: "\f58c";
}

.mdi-shuffle-disabled:before {
  content: "\f58d";
}

.mdi-shuffle-variant:before {
  content: "\f58e";
}

.mdi-sigma:before {
  content: "\f58f";
}

.mdi-sign-caution:before {
  content: "\f590";
}

.mdi-signal:before {
  content: "\f591";
}

.mdi-silverware:before {
  content: "\f592";
}

.mdi-silverware-fork:before {
  content: "\f593";
}

.mdi-silverware-spoon:before {
  content: "\f594";
}

.mdi-silverware-variant:before {
  content: "\f595";
}

.mdi-sim:before {
  content: "\f596";
}

.mdi-sim-alert:before {
  content: "\f597";
}

.mdi-sim-off:before {
  content: "\f598";
}

.mdi-sitemap:before {
  content: "\f599";
}

.mdi-skip-backward:before {
  content: "\f59a";
}

.mdi-skip-forward:before {
  content: "\f59b";
}

.mdi-skip-next:before {
  content: "\f59c";
}

.mdi-skip-previous:before {
  content: "\f59d";
}

.mdi-skype:before {
  content: "\f59e";
}

.mdi-skype-business:before {
  content: "\f59f";
}

.mdi-slack:before {
  content: "\f5a0";
}

.mdi-sleep:before {
  content: "\f5a1";
}

.mdi-sleep-off:before {
  content: "\f5a2";
}

.mdi-smoking:before {
  content: "\f5a3";
}

.mdi-smoking-off:before {
  content: "\f5a4";
}

.mdi-snapchat:before {
  content: "\f5a5";
}

.mdi-snowman:before {
  content: "\f5a6";
}

.mdi-sofa:before {
  content: "\f5a7";
}

.mdi-sort:before {
  content: "\f5a8";
}

.mdi-sort-alphabetical:before {
  content: "\f5a9";
}

.mdi-sort-ascending:before {
  content: "\f5aa";
}

.mdi-sort-descending:before {
  content: "\f5ab";
}

.mdi-sort-numeric:before {
  content: "\f5ac";
}

.mdi-sort-variant:before {
  content: "\f5ad";
}

.mdi-soundcloud:before {
  content: "\f5ae";
}

.mdi-source-fork:before {
  content: "\f5af";
}

.mdi-source-pull:before {
  content: "\f5b0";
}

.mdi-speaker:before {
  content: "\f5b1";
}

.mdi-speaker-off:before {
  content: "\f5b2";
}

.mdi-speedometer:before {
  content: "\f5b3";
}

.mdi-spellcheck:before {
  content: "\f5b4";
}

.mdi-spotify:before {
  content: "\f5b5";
}

.mdi-spotlight:before {
  content: "\f5b6";
}

.mdi-spotlight-beam:before {
  content: "\f5b7";
}

.mdi-square-inc:before {
  content: "\f5b8";
}

.mdi-square-inc-cash:before {
  content: "\f5b9";
}

.mdi-stackoverflow:before {
  content: "\f5ba";
}

.mdi-stairs:before {
  content: "\f5bb";
}

.mdi-star:before {
  content: "\f5bc";
}

.mdi-star-circle:before {
  content: "\f5bd";
}

.mdi-star-half:before {
  content: "\f5be";
}

.mdi-star-off:before {
  content: "\f5bf";
}

.mdi-star-outline:before {
  content: "\f5c0";
}

.mdi-steam:before {
  content: "\f5c1";
}

.mdi-steering:before {
  content: "\f5c2";
}

.mdi-step-backward:before {
  content: "\f5c3";
}

.mdi-step-backward-2:before {
  content: "\f5c4";
}

.mdi-step-forward:before {
  content: "\f5c5";
}

.mdi-step-forward-2:before {
  content: "\f5c6";
}

.mdi-stethoscope:before {
  content: "\f5c7";
}

.mdi-stocking:before {
  content: "\f5c8";
}

.mdi-stop:before {
  content: "\f5c9";
}

.mdi-store:before {
  content: "\f5ca";
}

.mdi-store-24-hour:before {
  content: "\f5cb";
}

.mdi-stove:before {
  content: "\f5cc";
}

.mdi-subway:before {
  content: "\f5cd";
}

.mdi-sunglasses:before {
  content: "\f5ce";
}

.mdi-swap-horizontal:before {
  content: "\f5cf";
}

.mdi-swap-vertical:before {
  content: "\f5d0";
}

.mdi-swim:before {
  content: "\f5d1";
}

.mdi-switch:before {
  content: "\f5d2";
}

.mdi-sword:before {
  content: "\f5d3";
}

.mdi-sync:before {
  content: "\f5d4";
}

.mdi-sync-alert:before {
  content: "\f5d5";
}

.mdi-sync-off:before {
  content: "\f5d6";
}

.mdi-tab:before {
  content: "\f5d7";
}

.mdi-tab-unselected:before {
  content: "\f5d8";
}

.mdi-table:before {
  content: "\f5d9";
}

.mdi-table-column-plus-after:before {
  content: "\f5da";
}

.mdi-table-column-plus-before:before {
  content: "\f5db";
}

.mdi-table-column-remove:before {
  content: "\f5dc";
}

.mdi-table-column-width:before {
  content: "\f5dd";
}

.mdi-table-edit:before {
  content: "\f5de";
}

.mdi-table-large:before {
  content: "\f5df";
}

.mdi-table-row-height:before {
  content: "\f5e0";
}

.mdi-table-row-plus-after:before {
  content: "\f5e1";
}

.mdi-table-row-plus-before:before {
  content: "\f5e2";
}

.mdi-table-row-remove:before {
  content: "\f5e3";
}

.mdi-tablet:before {
  content: "\f5e4";
}

.mdi-tablet-android:before {
  content: "\f5e5";
}

.mdi-tablet-ipad:before {
  content: "\f5e6";
}

.mdi-tag:before {
  content: "\f5e7";
}

.mdi-tag-faces:before {
  content: "\f5e8";
}

.mdi-tag-multiple:before {
  content: "\f5e9";
}

.mdi-tag-outline:before {
  content: "\f5ea";
}

.mdi-tag-text-outline:before {
  content: "\f5eb";
}

.mdi-target:before {
  content: "\f5ec";
}

.mdi-taxi:before {
  content: "\f5ed";
}

.mdi-teamviewer:before {
  content: "\f5ee";
}

.mdi-telegram:before {
  content: "\f5ef";
}

.mdi-television:before {
  content: "\f5f0";
}

.mdi-television-guide:before {
  content: "\f5f1";
}

.mdi-temperature-celsius:before {
  content: "\f5f2";
}

.mdi-temperature-fahrenheit:before {
  content: "\f5f3";
}

.mdi-temperature-kelvin:before {
  content: "\f5f4";
}

.mdi-tennis:before {
  content: "\f5f5";
}

.mdi-tent:before {
  content: "\f5f6";
}

.mdi-terrain:before {
  content: "\f5f7";
}

.mdi-text-to-speech:before {
  content: "\f5f8";
}

.mdi-text-to-speech-off:before {
  content: "\f5f9";
}

.mdi-texture:before {
  content: "\f5fa";
}

.mdi-theater:before {
  content: "\f5fb";
}

.mdi-theme-light-dark:before {
  content: "\f5fc";
}

.mdi-thermometer:before {
  content: "\f5fd";
}

.mdi-thermometer-lines:before {
  content: "\f5fe";
}

.mdi-thumb-down:before {
  content: "\f5ff";
}

.mdi-thumb-down-outline:before {
  content: "\f600";
}

.mdi-thumb-up:before {
  content: "\f601";
}

.mdi-thumb-up-outline:before {
  content: "\f602";
}

.mdi-thumbs-up-down:before {
  content: "\f603";
}

.mdi-ticket:before {
  content: "\f604";
}

.mdi-ticket-account:before {
  content: "\f605";
}

.mdi-ticket-confirmation:before {
  content: "\f606";
}

.mdi-tie:before {
  content: "\f607";
}

.mdi-timelapse:before {
  content: "\f608";
}

.mdi-timer:before {
  content: "\f609";
}

.mdi-timer-10:before {
  content: "\f60a";
}

.mdi-timer-3:before {
  content: "\f60b";
}

.mdi-timer-off:before {
  content: "\f60c";
}

.mdi-timer-sand:before {
  content: "\f60d";
}

.mdi-timetable:before {
  content: "\f60e";
}

.mdi-toggle-switch:before {
  content: "\f60f";
}

.mdi-toggle-switch-off:before {
  content: "\f610";
}

.mdi-tooltip:before {
  content: "\f611";
}

.mdi-tooltip-edit:before {
  content: "\f612";
}

.mdi-tooltip-image:before {
  content: "\f613";
}

.mdi-tooltip-outline:before {
  content: "\f614";
}

.mdi-tooltip-outline-plus:before {
  content: "\f615";
}

.mdi-tooltip-text:before {
  content: "\f616";
}

.mdi-tor:before {
  content: "\f617";
}

.mdi-traffic-light:before {
  content: "\f618";
}

.mdi-train:before {
  content: "\f619";
}

.mdi-tram:before {
  content: "\f61a";
}

.mdi-transcribe:before {
  content: "\f61b";
}

.mdi-transcribe-close:before {
  content: "\f61c";
}

.mdi-transfer:before {
  content: "\f61d";
}

.mdi-tree:before {
  content: "\f61e";
}

.mdi-trello:before {
  content: "\f61f";
}

.mdi-trending-down:before {
  content: "\f620";
}

.mdi-trending-neutral:before {
  content: "\f621";
}

.mdi-trending-up:before {
  content: "\f622";
}

.mdi-triangle:before {
  content: "\f623";
}

.mdi-triangle-outline:before {
  content: "\f624";
}

.mdi-trophy:before {
  content: "\f625";
}

.mdi-trophy-award:before {
  content: "\f626";
}

.mdi-trophy-outline:before {
  content: "\f627";
}

.mdi-trophy-variant:before {
  content: "\f628";
}

.mdi-trophy-variant-outline:before {
  content: "\f629";
}

.mdi-truck:before {
  content: "\f62a";
}

.mdi-truck-delivery:before {
  content: "\f62b";
}

.mdi-tshirt-crew:before {
  content: "\f62c";
}

.mdi-tshirt-v:before {
  content: "\f62d";
}

.mdi-tumblr:before {
  content: "\f62e";
}

.mdi-tumblr-reblog:before {
  content: "\f62f";
}

.mdi-twitch:before {
  content: "\f630";
}

.mdi-twitter:before {
  content: "\f631";
}

.mdi-twitter-box:before {
  content: "\f632";
}

.mdi-twitter-circle:before {
  content: "\f633";
}

.mdi-twitter-retweet:before {
  content: "\f634";
}

.mdi-ubuntu:before {
  content: "\f635";
}

.mdi-umbraco:before {
  content: "\f636";
}

.mdi-umbrella:before {
  content: "\f637";
}

.mdi-umbrella-outline:before {
  content: "\f638";
}

.mdi-undo:before {
  content: "\f639";
}

.mdi-undo-variant:before {
  content: "\f63a";
}

.mdi-unfold-less:before {
  content: "\f63b";
}

.mdi-unfold-more:before {
  content: "\f63c";
}

.mdi-ungroup:before {
  content: "\f63d";
}

.mdi-untappd:before {
  content: "\f63e";
}

.mdi-upload:before {
  content: "\f63f";
}

.mdi-usb:before {
  content: "\f640";
}

.mdi-vector-arrange-above:before {
  content: "\f641";
}

.mdi-vector-arrange-below:before {
  content: "\f642";
}

.mdi-vector-circle:before {
  content: "\f643";
}

.mdi-vector-circle-variant:before {
  content: "\f644";
}

.mdi-vector-combine:before {
  content: "\f645";
}

.mdi-vector-curve:before {
  content: "\f646";
}

.mdi-vector-difference:before {
  content: "\f647";
}

.mdi-vector-difference-ab:before {
  content: "\f648";
}

.mdi-vector-difference-ba:before {
  content: "\f649";
}

.mdi-vector-intersection:before {
  content: "\f64a";
}

.mdi-vector-line:before {
  content: "\f64b";
}

.mdi-vector-point:before {
  content: "\f64c";
}

.mdi-vector-polygon:before {
  content: "\f64d";
}

.mdi-vector-polyline:before {
  content: "\f64e";
}

.mdi-vector-selection:before {
  content: "\f64f";
}

.mdi-vector-square:before {
  content: "\f650";
}

.mdi-vector-triangle:before {
  content: "\f651";
}

.mdi-vector-union:before {
  content: "\f652";
}

.mdi-verified:before {
  content: "\f653";
}

.mdi-vibrate:before {
  content: "\f654";
}

.mdi-video:before {
  content: "\f655";
}

.mdi-video-off:before {
  content: "\f656";
}

.mdi-video-switch:before {
  content: "\f657";
}

.mdi-view-agenda:before {
  content: "\f658";
}

.mdi-view-array:before {
  content: "\f659";
}

.mdi-view-carousel:before {
  content: "\f65a";
}

.mdi-view-column:before {
  content: "\f65b";
}

.mdi-view-dashboard:before {
  content: "\f65c";
}

.mdi-view-day:before {
  content: "\f65d";
}

.mdi-view-grid:before {
  content: "\f65e";
}

.mdi-view-headline:before {
  content: "\f65f";
}

.mdi-view-list:before {
  content: "\f660";
}

.mdi-view-module:before {
  content: "\f661";
}

.mdi-view-quilt:before {
  content: "\f662";
}

.mdi-view-stream:before {
  content: "\f663";
}

.mdi-view-week:before {
  content: "\f664";
}

.mdi-vimeo:before {
  content: "\f665";
}

.mdi-vine:before {
  content: "\f666";
}

.mdi-vk:before {
  content: "\f667";
}

.mdi-vk-box:before {
  content: "\f668";
}

.mdi-vk-circle:before {
  content: "\f669";
}

.mdi-voicemail:before {
  content: "\f66a";
}

.mdi-volume-high:before {
  content: "\f66b";
}

.mdi-volume-low:before {
  content: "\f66c";
}

.mdi-volume-medium:before {
  content: "\f66d";
}

.mdi-volume-off:before {
  content: "\f66e";
}

.mdi-vpn:before {
  content: "\f66f";
}

.mdi-walk:before {
  content: "\f670";
}

.mdi-wallet:before {
  content: "\f671";
}

.mdi-wallet-giftcard:before {
  content: "\f672";
}

.mdi-wallet-membership:before {
  content: "\f673";
}

.mdi-wallet-travel:before {
  content: "\f674";
}

.mdi-wan:before {
  content: "\f675";
}

.mdi-watch:before {
  content: "\f676";
}

.mdi-watch-export:before {
  content: "\f677";
}

.mdi-watch-import:before {
  content: "\f678";
}

.mdi-water:before {
  content: "\f679";
}

.mdi-water-off:before {
  content: "\f67a";
}

.mdi-water-percent:before {
  content: "\f67b";
}

.mdi-water-pump:before {
  content: "\f67c";
}

.mdi-weather-cloudy:before {
  content: "\f67d";
}

.mdi-weather-fog:before {
  content: "\f67e";
}

.mdi-weather-hail:before {
  content: "\f67f";
}

.mdi-weather-lightning:before {
  content: "\f680";
}

.mdi-weather-night:before {
  content: "\f681";
}

.mdi-weather-partlycloudy:before {
  content: "\f682";
}

.mdi-weather-pouring:before {
  content: "\f683";
}

.mdi-weather-rainy:before {
  content: "\f684";
}

.mdi-weather-snowy:before {
  content: "\f685";
}

.mdi-weather-sunny:before {
  content: "\f686";
}

.mdi-weather-sunset:before {
  content: "\f687";
}

.mdi-weather-sunset-down:before {
  content: "\f688";
}

.mdi-weather-sunset-up:before {
  content: "\f689";
}

.mdi-weather-windy:before {
  content: "\f68a";
}

.mdi-weather-windy-variant:before {
  content: "\f68b";
}

.mdi-web:before {
  content: "\f68c";
}

.mdi-webcam:before {
  content: "\f68d";
}

.mdi-weight:before {
  content: "\f68e";
}

.mdi-weight-kilogram:before {
  content: "\f68f";
}

.mdi-whatsapp:before {
  content: "\f690";
}

.mdi-wheelchair-accessibility:before {
  content: "\f691";
}

.mdi-white-balance-auto:before {
  content: "\f692";
}

.mdi-white-balance-incandescent:before {
  content: "\f693";
}

.mdi-white-balance-irradescent:before {
  content: "\f694";
}

.mdi-white-balance-sunny:before {
  content: "\f695";
}

.mdi-wifi:before {
  content: "\f696";
}

.mdi-wifi-off:before {
  content: "\f697";
}

.mdi-wii:before {
  content: "\f698";
}

.mdi-wikipedia:before {
  content: "\f699";
}

.mdi-window-close:before {
  content: "\f69a";
}

.mdi-window-closed:before {
  content: "\f69b";
}

.mdi-window-maximize:before {
  content: "\f69c";
}

.mdi-window-minimize:before {
  content: "\f69d";
}

.mdi-window-open:before {
  content: "\f69e";
}

.mdi-window-restore:before {
  content: "\f69f";
}

.mdi-windows:before {
  content: "\f6a0";
}

.mdi-wordpress:before {
  content: "\f6a1";
}

.mdi-worker:before {
  content: "\f6a2";
}

.mdi-wrap:before {
  content: "\f6a3";
}

.mdi-wrench:before {
  content: "\f6a4";
}

.mdi-wunderlist:before {
  content: "\f6a5";
}

.mdi-xbox:before {
  content: "\f6a6";
}

.mdi-xbox-controller:before {
  content: "\f6a7";
}

.mdi-xbox-controller-off:before {
  content: "\f6a8";
}

.mdi-xda:before {
  content: "\f6a9";
}

.mdi-xing:before {
  content: "\f6aa";
}

.mdi-xing-box:before {
  content: "\f6ab";
}

.mdi-xing-circle:before {
  content: "\f6ac";
}

.mdi-xml:before {
  content: "\f6ad";
}

.mdi-yeast:before {
  content: "\f6ae";
}

.mdi-yelp:before {
  content: "\f6af";
}

.mdi-youtube-play:before {
  content: "\f6b0";
}

.mdi-zip-box:before {
  content: "\f6b1";
}

.mdi-18px {
  font-size: 18px;
}

.mdi-24px {
  font-size: 24px;
}

.mdi-36px {
  font-size: 36px;
}

.mdi-48px {
  font-size: 48px;
}

.mdi-dark {
  color: rgba(0, 0, 0, 0.54);
}

.mdi-dark.mdi-inactive {
  color: rgba(0, 0, 0, 0.26);
}

.mdi-light {
  color: white;
}

.mdi-light.mdi-inactive {
  color: rgba(255, 255, 255, 0.3);
}

/*# sourceMappingURL=materialdesignicons.css.map */
